# Authors credits

The main instigators and developers of COOLEST are the following people:
- Aymeric Galan, [@aymgal](https://github.com/aymgal)
- Lyne Van de Vyvere, [@LyneVdV](https://github.com/LyneVdV)
- Matt Gomer, [@mattgomer](https://github.com/mattgomer)
- Georgios Vernardos, [@gvernard](https://github.com/gvernard)
- Dominique Sluse, [@dsluse](https://github.com/dsluse)
